==> piwigo-2.1.5.zip: piwigo/plugins/LocalFilesEditor/language/ka_GE/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based picture gallery                                  |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2010 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['locfiledit_onglet_localconf'] = 'ლოკალური კონფიგურაცია';
$lang['locfiledit_onglet_css'] = 'CSS';
$lang['locfiledit_onglet_tpl'] = 'შაბლონები';
$lang['locfiledit_onglet_lang'] = 'ენები';
$lang['locfiledit_onglet_plug'] = 'პერსონალური პლაგინი';
$lang['locfiledit_cant_save'] = 'ეს ფაილი არ არის ჩაწერის უფლებით. შეამოწმეთ დირექტორია "include/" არის თუ არა შესაბამისი (chmod)–ით.';
$lang['locfiledit_newfile'] = 'ფაილი არ არსებობს და შეიქმნება LocalFiles რედაქტორის მიერ ';
$lang['locfiledit_save_config'] = 'ფაილი წარმატებით წაიკითხა.';
$lang['locfiledit_show_default'] = 'ვნახოთ გასასწორებელი ფაილი: ';
$lang['locfiledit_save_bak'] = 'სარეზერვო ასლი შეიქმნა და შეინახა.';
$lang['locfiledit_saved_bak'] = 'სარეზერვო ასლი შეიქმნა (%s) –ით';
$lang['locfiledit_save_file'] = 'შევინახოთ ფაილი';
$lang['locfiledit_choose_file'] = 'აირჩიეთ ფაილი რედაქტირებისათვის';
$lang['locfiledit_edit'] = 'რედაქტირება';
$lang['locfiledit_restore'] = 'სარეზერვო ფაილის აღდგენა';
$lang['locfiledit_restore_confirm'] = 'გთხოვთ დაადასტუროთ?
აღდგენა არ იქნება ეფექტური მომდევნო შენახვამდე.';
$lang['locfiledit_bak_loaded1'] = 'სარეზერვო ფაილის ჩატვირთვა.';
$lang['locfiledit_bak_loaded2'] = 'თქვენ უნდა შეინახოთ ფაილი, რომ აღდგინოთ.';
$lang['locfiledit_syntax_error'] = 'სინტაქსური შეცდომა! ფაილი ვერ შეინახება.';
$lang['locfiledit_enable_editarea'] = 'ჩავრთოთ გასასწორებელი ველი';
$lang['locfiledit_disable_editarea'] = 'გამოვრთოთ გასასწორებელი ველი';
$lang['locfiledit_new_tpl'] = 'შევქმნათ ახალი ფაილი';
$lang['locfiledit_new_filename'] = 'ფაილის სახელი';
$lang['locfiledit_model'] = 'მოდელი';
$lang['locfiledit_empty_page'] = 'ცარიელი გვერდი';
$lang['locfiledit_parent_directory'] = 'მშობლიური დირექტორია';
$lang['locfiledit_filename_error'] = 'აკრძალული სიმბოლოები ფაილის სახელში.';
$lang['locfiledit_file_already_exists'] = 'ფაილი უკვე არსებობს.';
$lang['locfiledit_model_error'] = 'თქვენ უნდა აირჩიოთ მოდელი.';
$lang['locfiledit_empty_filename'] = 'თქვენ უნდა შეავსოთ ფაილის სახელი.';
$lang['locfiledit_webmaster_only'] = 'მხოლოდ ვებოსტატებს შეუძლიათ შექმნან ან გადააკეთონ ლოკალური ფაილები.';

?>

==> piwigo-2.1.6.zip: piwigo/plugins/LocalFilesEditor/language/ka_GE/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based picture gallery                                  |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2010 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['locfiledit_onglet_localconf'] = 'ლოკალური კონფიგურაცია';
$lang['locfiledit_onglet_css'] = 'CSS';
$lang['locfiledit_onglet_tpl'] = 'შაბლონები';
$lang['locfiledit_onglet_lang'] = 'ენები';
$lang['locfiledit_onglet_plug'] = 'პერსონალური პლაგინი';
$lang['locfiledit_cant_save'] = 'ეს ფაილი არ არის ჩაწერის უფლებით. შეამოწმეთ დირექტორია "local/" არის თუ არა შესაბამისი (chmod)–ით.';
$lang['locfiledit_newfile'] = 'ფაილი არ არსებობს და შეიქმნება LocalFiles რედაქტორის მიერ ';
$lang['locfiledit_save_config'] = 'ფაილი წარმატებით წაიკითხა.';
$lang['locfiledit_show_default'] = 'ვნახოთ გასასწორებელი ფაილი: ';
$lang['locfiledit_save_bak'] = 'სარეზერვო ასლი შეიქმნა და შეინახა.';
$lang['locfiledit_saved_bak'] = 'სარეზერვო ასლი შეიქმნა (%s) –ით';
$lang['locfiledit_save_file'] = 'შევინახოთ ფაილი';
$lang['locfiledit_choose_file'] = 'აირჩიეთ ფაილი რედაქტირებისათვის';
$lang['locfiledit_edit'] = 'რედაქტირება';
$lang['locfiledit_restore'] = 'სარეზერვო ფაილის აღდგენა';
$lang['locfiledit_restore_confirm'] = 'გთხოვთ დაადასტუროთ?
აღდგენა არ იქნება ეფექტური მომდევნო შენახვამდე.';
$lang['locfiledit_bak_loaded1'] = 'სარეზერვო ფაილის ჩატვირთვა.';
$lang['locfiledit_bak_loaded2'] = 'თქვენ უნდა შეინახოთ ფაილი, რომ აღდგინოთ.';
$lang['locfiledit_syntax_error'] = 'სინტაქსური შეცდომა! ფაილი ვერ შეინახება.';
$lang['locfiledit_enable_editarea'] = 'ჩავრთოთ გასასწორებელი ველი';
$lang['locfiledit_disable_editarea'] = 'გამოვრთოთ გასასწორებელი ველი';
$lang['locfiledit_new_tpl'] = 'შევქმნათ ახალი ფაილი';
$lang['locfiledit_new_filename'] = 'ფაილის სახელი';
$lang['locfiledit_model'] = 'მოდელი';
$lang['locfiledit_empty_page'] = 'ცარიელი გვერდი';
$lang['locfiledit_parent_directory'] = 'მშობლიური დირექტორია';
$lang['locfiledit_filename_error'] = 'აკრძალული სიმბოლოები ფაილის სახელში.';
$lang['locfiledit_file_already_exists'] = 'ფაილი უკვე არსებობს.';
$lang['locfiledit_model_error'] = 'თქვენ უნდა აირჩიოთ მოდელი.';
$lang['locfiledit_empty_filename'] = 'თქვენ უნდა შეავსოთ ფაილის სახელი.';
$lang['locfiledit_webmaster_only'] = 'მხოლოდ ვებოსტატებს შეუძლიათ შექმნან ან გადააკეთონ ლოკალური ფაილები.';

?>
